.. |pypi| image:: https://img.shields.io/pypi/v/wsh.svg?style=flat-square
    :target: https://pypi.python.org/pypi/wsh
.. |license| image:: https://img.shields.io/pypi/l/wsh.svg?style=flat-square
    :target: https://pypi.python.org/pypi/wsh

****
WSH
****
|pypi| |license| 

WSH is a command line interface that launches a shell to send and recieve
messages from a WebSocket server. It was designed to be simplistic and allow
developers to easily connect/send/receive data over a WS with very little effort.


.. image:: https://thumbs.gfycat.com/SlimUncomfortableCanary-size_restricted.gif
   :align: center


https://wsh.readthedocs.io

